# ekstremalpunkt_max()
#from .ekstremalpunkt_max_fil import (
#    ekstremalpunkt_max,
#    #superløs,
#    #Symbol,
#    #diff
#    )
#from .ekstremalpunkt_maks_fil import (
#    ekstremalpunkt_maks,
#    superløs,
#    Symbol,
#    diff
#    )

# overskudd_max()
from .overskudd_max_fil import (
    overskudd_max,
    #ekstremalpunkt_max,
    #Symbol
    )
#from .overskudd_maks_fil import (
#    overskudd_maks,
#    ekstremalpunkt_max,
#    Symbol
#    )

# reggis()
from .reggis_fil import (
    reggis,
    #polyfit,
    #Symbol
    )
from .reggis_cas_fil import (
    reggis_cas,
    #polyfit,
    #Symbol
    )

# superlos()
from .superløs_fil import (
    superløs,
    Eq,
    Reals,
    core,
    Symbol,
    ConditionSet,
    FiniteSet,
    Intersection,
    solve,
    solveset,
    nsolve
    )
#from .superlos_fil import (
#    superlos,
#    Eq,
#    Reals,
#    core,
#    Symbol,
#    ConditionSet,
#    FiniteSet,
#    Intersection,
#    solve,
#    solveset,
#    nsolve
#    )

